diff libinterp/parse-tree/pt-tm-const.cc @ 28631:70cdf8de553d

move non-member octave_value operator functions to octave namespace * ov.h, ov.cc (unary_op, binary_op, cat_op, colon_op): New functions in octave namespace that replace do_unary_op, do_binary_op, do_cat_op, and do_colon_op, respectively. (do_unary_op, do_binary_op, do_cat_op, do_colon_op): Deprecate global functions. Forward to corresponding new functions in octave namespace. * bsxfun.cc, cellfun.cc, data.cc, dot.cc, fft.cc, oct-stream.cc, stack-frame.h, tril.cc, ov-base-diag.cc, ov-bool.cc, ov-class.cc, ov-complex.cc, ov-float.cc, ov-flt-complex.cc, ov-intx.h, ov-lazy-idx.h, ov-magic-int.cc, ov-perm.cc, ov-range.cc, ov-scalar.cc, oct-lvalue.cc, oct-lvalue.h, pt-binop.cc, pt-cbinop.cc, pt-colon.cc, pt-eval.cc, pt-tm-const.cc, pt-unop.cc: Change all uses.
author John W. Eaton <jwe@octave.org>
date Thu, 30 Jul 2020 16:16:04 -0400
parents 713398d4a3c3
children 7854d5752dd2
line wrap: on
line diff
--- a/libinterp/parse-tree/pt-tm-const.cc	Thu Jul 30 16:15:03 2020 -0400
+++ b/libinterp/parse-tree/pt-tm-const.cc	Thu Jul 30 16:16:04 2020 -0400
@@ -461,7 +461,7 @@
     // full.  This is done since it means that there is no recopying of
     // data, as would happen if we used a single resize.  It should be
     // noted that resize operation is also significantly slower than the
     // do_cat_op function, so it makes sense to have an empty matrix and
     // copy all data.
     //
     // We might also start with a empty octave_value using
@@ -532,7 +532,7 @@
             if (elt.isempty ())
               continue;
 
-            ctmp = do_cat_op (ti, ctmp, elt, ra_idx);
+            ctmp = cat_op (ti, ctmp, elt, ra_idx);
 
             ra_idx (1) += elt.columns ();
           }
@@ -461,7 +461,7 @@
     // data, as would happen if we used a single resize.  It should be
     // noted that resize operation is also significantly slower than the
-    // do_cat_op function, so it makes sense to have an empty matrix and
+    // cat_op function, so it makes sense to have an empty matrix and
     // copy all data.
     //